package principal;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sun.rowset.*;

/**
 * Clase con métodos utiles para el manejo de una colección de conexiones 
 * abiertas a una base de datos de manera que puedan ser reutilizadas al
 * realizar múltiples consultas o actualizaciones.
 * @author Palacios Trejo Armando ciencias UNAM
 */
public class ConexionBases {
	/** Logger. */
	private static Log log = LogFactory.getLog(ConexionBases.class);

	/**
	 * Realiza una consulta en la base de datos.
	 * @param query La consulta a realizar en la BD.
	 * @return Los resultados de la consulta en forma de Resultset.
	 */
	@SuppressWarnings("restriction")
	public static CachedRowSetImpl consulta(String query) {
		Connection conexion = null;
		Statement statement = null;
		ResultSet resultSet = null;
		CachedRowSetImpl cachedRowSet = null;
		try {
			conexion = PrimerPortlet.getFuenteDatos().getConnection();
			statement = conexion.createStatement();
			resultSet = statement.executeQuery(query);
			/*
			 *  Crea un CachedRowSet para poder usar los datos del ResultSet
			 *  después de cerrar la conexión a la BD.
			 */
			cachedRowSet = new CachedRowSetImpl();
			cachedRowSet.populate(resultSet);

		} catch (SQLException e) {
			log.error(e.getMessage());
			e.printStackTrace();
		} finally {
			try {
				if (resultSet != null) {
					resultSet.close();
					resultSet = null;
				}
				if (statement != null) {
					statement.close();
					statement = null;
				}
				if (conexion != null) {
					conexion.close();
					conexion = null;
				}
			} catch (SQLException e) {
				log.error(e.getMessage());
			}
		}

		return cachedRowSet;
	}

}
