package principal;

import java.io.IOException;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.PortletSession;
import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Clase principal que administra las demas clases.
 * @author Palacios Trejo Armando ciencias UNAM
 */
public class PrimerPortlet extends GenericPortlet{
	/** Logger. */
	private static Log log = LogFactory.getLog(PrimerPortlet.class);
	/** Fuente de datos para conectar con la BD. */
	private static DataSource fuenteDatos;
	/** Nombre del POOL de la BD. */
	public static final String POOL_CONEXIONES = "jdbc/LiferayPool";
	/** Campo necesario para el método doView del portlet. */
	private String viewJSP;

	static {
		try {
			fuenteDatos =
				(DataSource) new InitialContext().lookup(POOL_CONEXIONES);
		} catch (NamingException e) {
			throw new ExceptionInInitializerError(e);
		}
	}
	
    /**
     * Atiende peticiones de tipo actionUrl para subir archivos al servidor.
     */
    @SuppressWarnings("unchecked")
    @Override
    public synchronized void processAction(ActionRequest req,
            ActionResponse resp) throws IOException, PortletException {

    }

	/**
	 * Manda el flujo a donde sea necesario según un parámetro del request.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 * @throws IOException Si hay error de entrada/salida.
	 * @throws PortletException Si hay error en el portlet.
	 */
	@Override
	public void doDispatch(RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		PortletSession sesion = req.getPortletSession(true);
		String accion = req.getParameter("accion");
		if (accion == null) {
			super.doDispatch(req, resp);
			return;
		} else if (accion.equals("resultados")) {
			muestraResultados(req, resp);
			return;
		} else if (accion.equals("limpiaBusqueda")) {
			sesion.removeAttribute("listaResultado");
			include(viewJSP, req, resp);
			return;
		}
	}

	/**
	 * @return La fuente de datos para conexiones con la BD.
	 */
	public static DataSource getFuenteDatos() {
		return fuenteDatos;
	}

	/**
	 * Inicializa variables necesarias para el portlet.
	 */
	@Override
	public void init() throws PortletException {
		this.viewJSP = getInitParameter("view-jsp");
	}

	/**
	 * Método auxiliar para redirigir una petición.
	 * @param ruta La ruta para redirigir la petición.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 * @throws IOException Si hay error de entrada/salida.
	 * @throws PortletException Si hay error en el portlet.
	 */
	private void include(String ruta, RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		PortletRequestDispatcher portletRequestDispatcher = getPortletContext()
		.getRequestDispatcher(ruta);
		if (portletRequestDispatcher == null) {
			log.error(ruta + " es una ruta incorrecta");
		} else {
			portletRequestDispatcher.include(req, resp);
		}
	}

	/**
	 * Atiende una petición de view del portlet.
	 */
	@Override
	public void doView(RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		include(viewJSP, req, resp);
	}

	/**
	 * Regresa "" si la entrada es null, si no regresa el mismo String.
	 * @param string El String a revisar.
	 * @return Un String diferente de null.
	 */
	public static String denullify(String string) {
		if (string == null) {
			string = "";
		}
		return string;
	}

	/**
	 * Muestra los resultados de la consulta.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 * @throws IOException Si hay error de entrada/salida.
	 * @throws PortletException Si hay error en el portlet.
	 */
	private void muestraResultados(RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		PortletSession sesion = req.getPortletSession(true);
		sesion.setAttribute("nombre", denullify(req.getParameter("nombre")));
		sesion.setAttribute("apellido",denullify(req.getParameter("apellido")));
		include("/resultados.jsp", Modelo.obtenResultados(
				req,
				sesion.getAttribute("nombre").toString(),
				sesion.getAttribute("apellido").toString()
		), resp);
	}

}
