package controlador;

import java.io.IOException;


import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import modelos.Main;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Clase principal que administra las demas clases.
 * @author Palacios Trejo Armando ciencias UNAM
 */
public class Controlador extends GenericPortlet{
	/** Logger. */
	private static Log log = LogFactory.getLog(Controlador.class);
	/** Campo necesario para el método doView del portlet. */
	private String viewJSP;

	/**
	 * Atiende peticiones de tipo actionUrl para subir archivos al servidor.
	 * Y hace que cuando se haga una petición, la ventana permanezca normal.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 */
	@Override
	public synchronized void processAction(ActionRequest req,
			ActionResponse resp) throws IOException, PortletException {
	}

	/**
	 * Manda el flujo a donde sea necesario según un parámetro del request.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 * @throws IOException Si hay error de entrada/salida.
	 * @throws PortletException Si hay error en el portlet.
	 */
	@Override
	public void doDispatch(RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		String accion = req.getParameter("accion");
		if (accion == null) {
			super.doDispatch(req, resp);
			log.info("Grupos");
			Main obj = new Main();
			try {
				obj.listGrupo();
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			return;
		}
	}

	/**
	 * Inicializa variables necesarias para el portlet desde el portlet.xml.
	 */
	@Override
	public void init() throws PortletException {
		this.viewJSP = getInitParameter("view-jsp");
	}

	/**
	 * Método auxiliar para redirigir una petición.
	 * @param ruta La ruta para redirigir la petición.
	 * @param req El objeto request.
	 * @param resp El objeto response.
	 * @throws IOException Si hay error de entrada/salida.
	 * @throws PortletException Si hay error en el portlet.
	 */
	private void include(String ruta, RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		PortletRequestDispatcher portletRequestDispatcher = getPortletContext()
		.getRequestDispatcher(ruta);
		if (portletRequestDispatcher == null) {
			log.error(ruta + " es una ruta incorrecta");
		} else {
			portletRequestDispatcher.include(req, resp);
		}
	}

	/**
	 * Atiende una petición de view del portlet.
	 */
	@Override
	public void doView(RenderRequest req, RenderResponse resp)
	throws IOException, PortletException {
		include(viewJSP, req, resp);
	}

	/**
	 * Regresa "" si la entrada es null, si no regresa el mismo String.
	 * @param string El String a revisar.
	 * @return Un String diferente de null.
	 */
	public static String denullify(String string) {
		if (string == null) {
			string = "";
		}
		return string;
	}

}

